|
|
![](http://www.xen.org/images/globals/pixel.gif) |
|
|
|
|
|
|
|
xen-changelog
[Xen-changelog] [xen-unstable] [tools] Increases some of the timeouts
# HG changeset patch
# User Christian Limpach <Christian.Limpach@xxxxxxxxxxxxx>
# Node ID 39aaa54756dbc4723ae6e467404de2c3af6513e5
# Parent 93135bbb5344fda74ab5596a84e4a5c9715ae674
[tools] Increases some of the timeouts
since e.g. stealing the hotplug lock after five seconds is completely insane.
From: Steven Smith <sos22@xxxxxxxxx>
Signed-off-by: Christian Limpach <Christian.Limpach@xxxxxxxxxxxxx>
---
tools/examples/locking.sh | 2 +-
tools/ioemu/target-i386-dm/helper2.c | 4 ++--
tools/python/xen/xend/server/DevController.py | 2 +-
3 files changed, 4 insertions(+), 4 deletions(-)
diff -r 93135bbb5344 -r 39aaa54756db tools/examples/locking.sh
--- a/tools/examples/locking.sh Thu Sep 21 11:33:38 2006 +0100
+++ b/tools/examples/locking.sh Thu Sep 21 13:53:49 2006 +0100
@@ -21,7 +21,7 @@
LOCK_SLEEPTIME=1
LOCK_SPINNING_RETRIES=5
-LOCK_RETRIES=10
+LOCK_RETRIES=100
LOCK_BASEDIR=/var/run/xen-hotplug
diff -r 93135bbb5344 -r 39aaa54756db tools/ioemu/target-i386-dm/helper2.c
--- a/tools/ioemu/target-i386-dm/helper2.c Thu Sep 21 11:33:38 2006 +0100
+++ b/tools/ioemu/target-i386-dm/helper2.c Thu Sep 21 13:53:49 2006 +0100
@@ -520,8 +520,8 @@ int main_loop(void)
}
}
- /* Wait up to 10 msec. */
- main_loop_wait(10);
+ /* Wait up to 100 msec. */
+ main_loop_wait(100);
if (env->send_event) {
env->send_event = 0;
diff -r 93135bbb5344 -r 39aaa54756db
tools/python/xen/xend/server/DevController.py
--- a/tools/python/xen/xend/server/DevController.py Thu Sep 21 11:33:38
2006 +0100
+++ b/tools/python/xen/xend/server/DevController.py Thu Sep 21 13:53:49
2006 +0100
@@ -25,7 +25,7 @@ from xen.xend.xenstore.xstransact import
from xen.xend.xenstore.xstransact import xstransact, complete
from xen.xend.xenstore.xswatch import xswatch
-DEVICE_CREATE_TIMEOUT = 10
+DEVICE_CREATE_TIMEOUT = 100
HOTPLUG_STATUS_NODE = "hotplug-status"
HOTPLUG_ERROR_NODE = "hotplug-error"
HOTPLUG_STATUS_ERROR = "error"
_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog
|
<Prev in Thread] |
Current Thread |
[Next in Thread> |
- [Xen-changelog] [xen-unstable] [tools] Increases some of the timeouts,
Xen patchbot-unstable <=
|
|
|
|
|